/*
  Plee The Bear - Model compiler

  Copyright (C) 2005-2008 Julien Jorge, Sébastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file node_compiler_const_declaration.hpp
 * \brief Compile the node of the "const_declaration" rule.
 * \author Julien Jorge
 */
#ifndef __MC_NODE_COMPILER_CONST_DECLARATION_HPP__
#define __MC_NODE_COMPILER_CONST_DECLARATION_HPP__

#include "mc/model.hpp"
#include "mc/node_compiler/node_compiler.hpp"
#include "mc/symbol_table.hpp"

namespace mc
{
  /**
   * \brief Compile the node of the "const_declaration" rule.
   * \author Julien Jorge
   */
  class node_compiler_const_declaration:
    public node_compiler
  {
  public:
    void compile_node( symbol_table& symbols, const model& the_model,
                       const tree_node& node ) const;

  private:
    void add_u_integer( const std::string& name, symbol_table& symbols,
                        const tree_node& node ) const;
    void add_real( const std::string& name, symbol_table& symbols,
                   const tree_node& node ) const;
    void add_string( const std::string& name, symbol_table& symbols,
                     const tree_node& node ) const;
    void add_bool( const std::string& name, symbol_table& symbols,
                   const tree_node& node ) const;
    void add_image( const std::string& name, symbol_table& symbols,
                    const model& the_model, const tree_node& node ) const;
    void add_animation( const std::string& name, symbol_table& symbols,
                        const model& the_model, const tree_node& node ) const;
    void add_identifier( const std::string& name, symbol_table& symbols,
                         const tree_node& node ) const;

  }; // class node_compiler_const_declaration
} // namespace mc

#endif // __MC_NODE_COMPILER_CONST_DECLARATION_HPP__
